# DiskStoragePriceHr

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**disk_gib_price_hr** | [**Decimal**](Decimal.md) |  | [optional] 
**snapshot_gib_price_hr** | [**Decimal**](Decimal.md) |  | [optional] 
**storage_class** | [**VMDataCenterStorageClass**](VMDataCenterStorageClass.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


